# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/00_cons.ipynb.

# %% auto 0
__all__ = ['ALLATTRS']

# %% ../nbs/00_cons.ipynb 6
from math import nan as pynan

# %% ../nbs/00_cons.ipynb 8
from types import NoneType, FunctionType
from typing import (
    Self, Type, TypeVar, TypeGuard, TypeAlias, ParamSpec,
    Callable, Iterable, Optional, Protocol, _ProtocolMeta, 
    Any, Set, Dict, List, Tuple, Union, ClassVar, Generic, Literal,
    get_args, get_origin, runtime_checkable, overload, 
)

# %% ../nbs/00_cons.ipynb 10
#| export


# %% ../nbs/00_cons.ipynb 12
#| export


# %% ../nbs/00_cons.ipynb 14
#| export


# %% ../nbs/00_cons.ipynb 16
ALLATTRS = {'types', 'dtype', 'type'}
